﻿using System;
using System.Windows.Forms;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;


namespace GPStoGoogleMapDesktop
{
   public partial class TestForm : Form
   {
      public TestForm()
      {
         InitializeComponent();
      }

      private void TestForm_Load( object sender, EventArgs e )
      {
         winformsMap1.MapUnit = GeographyUnit.Meter;
         winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush( GeoColor.FromArgb( 255, 198, 255, 255 ) );

         LayerOverlay googleOverlay = new LayerOverlay();
         GoogleMapsLayer googleLayer = new GoogleMapsLayer();
         googleLayer.CacheDirectory = Application.StartupPath + @"\MapCache";
         googleLayer.MapType = GoogleMapsMapType.RoadMap;

         googleOverlay.Layers.Add( googleLayer );

         LayerOverlay staticOverlay = new LayerOverlay();
         ShapeFileFeatureLayer shapefileLayer = new ShapeFileFeatureLayer( @"C:\Documents and Settings\athielking\Desktop\Delta GIS\BSA\Delta_Parcels_2008.shp" );
         shapefileLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle( GeoColor.SimpleColors.Green, GeoColor.SimpleColors.Black );
         shapefileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

         staticOverlay.Layers.Add( shapefileLayer );

         winformsMap1.Overlays.Add( googleOverlay );
         winformsMap1.Overlays.Add( staticOverlay );

         // This sets the zoom levels to map to Googles.  We next make sure we snap to the zoomlevels
         winformsMap1.ZoomLevelSet = new GoogleMapZoomLevelSet();

         //Sets the projection parameters to go from Geodetic (EPSG 4326) or decimal degrees to Google Map projection (Spherical Mercator).
         Proj4Projection proj4 = new Proj4Projection();
         proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString( 4326 );
         proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();

         //Values in Longitude and Latitude.,  For middle of MI
         double Longitude = -84.772339;
         double Latitude = 43.598693;


         //Sets the extend of the map based on the GPS point.
         //
         // RectangleShape rs = ExtentHelper.ToWorldCoordinate( proj4.DecimalDegreeBoundary, new ScreenPointF( 302, 201 ), winformsMap1.Width, winformsMap1.Height);
         proj4.Open();
         Vertex vertex = proj4.ConvertToExternalProjection( Longitude, Latitude );
         proj4.Close();

         double extendWidth = 260000;
         double extendHeight = 150000;


         winformsMap1.CurrentExtent = new RectangleShape( (vertex.X - extendWidth), (vertex.Y + extendHeight), (vertex.X + extendWidth), (vertex.Y - extendHeight) );
         winformsMap1.Refresh();

      }


      private void winformsMap1_MouseMove( object sender, MouseEventArgs e )
      {
         //Displays the X and Y in screen coordinates.
         statusStrip1.Items["toolStripStatusLabelScreen"].Text = "X:" + e.X + " Y:" + e.Y;

         //Gets the PointShape in world coordinates from screen coordinates.
         PointShape pointShape = ExtentHelper.ToWorldCoordinate( winformsMap1.CurrentExtent, new ScreenPointF( e.X, e.Y ), winformsMap1.Width, winformsMap1.Height );

         //Displays world coordinates.
         statusStrip1.Items["toolStripStatusLabelWorld"].Text = "(world) X:" + Math.Round( pointShape.X, 4 ) + " Y:" + Math.Round( pointShape.Y, 4 );
      }

      private void btnClose_Click( object sender, EventArgs e )
      {
         this.Close();
      }

   }
}
